@@ -50,7 +50,7 @@ def add_log(context):
 def main():
     if len(sys.argv) > 1:
         if sys.argv[1][0] == '@':
-            add_log(sys.argv[1])
+            add_log(sys.argv[1][1:])
         else:
             show_usage()
     else:
